This repository contains Aspose.Storage Cloud SDK for Python source code. This SDK allows you to work with Aspose.Storage Cloud REST APIs in your Python applications quickly and easily, with zero initial cost. See [API Reference](https://apireference.aspose.cloud/storage/) for full API specification.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.1
- Package version: 1.0.6
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import asposestoragecloud 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import asposestoragecloud
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import asposestoragecloud
from asposestoragecloud.rest import ApiException
from pprint import pprint
# create an instance of the API class
api_instance = asposestoragecloud.StorageApi()
path = 'path_example' # str | Path of the file including file name and extension e.g. /Folder1/file.ext
version_id = 'version_id_example' # str | File's version (optional)
storage = 'storage_example' # str | User's storage name (optional)

try:
    # Remove a specific file 
    api_response = api_instance.delete_file(path, version_id=version_id, storage=storage)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling StorageApi->delete_file: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.aspose.cloud/v1.1*.

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*StorageApi* | **delete_file** | **DELETE** /storage/file | Remove a specific file
*StorageApi* | **delete_folder** | **DELETE** /storage/folder | Remove a specific folder
*StorageApi* | **get_disc_usage** | **GET** /storage/disc | Check the disk usage of the current account
*StorageApi* | **get_download** | **GET** /storage/file | Download a specific file
*StorageApi* | **get_is_exist** | **GET** /storage/exist | Check if a specific file or folder exists
*StorageApi* | **get_is_storage_exist** | **GET** /storage/{name}/exist | Check if storage exists
*StorageApi* | **get_list_file_versions** | **GET** /storage/version | Get the file&#39;s versions list
*StorageApi* | **get_list_files** | **GET** /storage/folder | Get the file listing of a specific folder
*StorageApi* | **post_move_file** | **POST** /storage/file | Move a specific file
*StorageApi* | **post_move_folder** | **POST** /storage/folder | Move a specific folder
*StorageApi* | **put_create** | **PUT** /storage/file | Upload a specific file
*StorageApi* | **put_create_folder** | **PUT** /storage/folder | Create the folder


## Documentation For Authorization


## appsid

- **Type**: API key
- **API key parameter name**: appsid
- **Location**: URL query string

## oauth

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: http://api.aspose.cloud/oauth2/token
- **Scopes**: N/A

## signature

- **Type**: API key
- **API key parameter name**: signature
- **Location**: URL query string


## Author



